@@ -4,24 +4,23 @@ from starlette.responses import Response
 
 from xpresso.applications import App
 from xpresso.bodies import (
-    ByContentType,
-    ExtractField,
-    ExtractRepeatedField,
+    BodyUnion,
     File,
     Form,
-    FormEncodedField,
     FormField,
+    FormFile,
+    FromBodyUnion,
     FromFile,
     FromFormData,
     FromFormField,
+    FromFormFile,
     FromJson,
     FromMultipart,
     Json,
     Multipart,
-    RepeatedFormField,
 )
 from xpresso.datastructures import BinaryStream, UploadFile
-from xpresso.dependencies.models import Depends
+from xpresso.dependencies import Depends
 from xpresso.exception_handlers import ExcHandler
 from xpresso.parameters import (
     CookieParam,
@@ -50,8 +49,8 @@ __all__ = (
     "CookieParam",
     "PathParam",
     "Json",
-    "ExtractField",
-    "ExtractRepeatedField",
+    "FormFile",
+    "FromFormFile",
     "Form",
     "File",
     "Multipart",
@@ -59,23 +58,22 @@ __all__ = (
     "App",
     "Router",
     "UploadFile",
+    "FromBodyUnion",
+    "BodyUnion",
     "FromCookie",
     "FromMultipart",
     "FromFormField",
     "FromFormData",
     "FromHeader",
     "FromJson",
-    "FormEncodedField",
+    "FormField",
     "FromPath",
     "FromQuery",
     "HTTPException",
-    "RepeatedFormField",
-    "FormField",
     "FromFile",
     "status",
     "Request",
     "Response",
-    "ByContentType",
     "WebSocketRoute",
     "WebSocket",
 )
