@@ -20,7 +20,7 @@ from starlette.websockets import WebSocket
 from xpresso._utils.asgi import XpressoHTTPExtension, XpressoWebSocketExtension
 from xpresso._utils.overrides import DependencyOverrideManager
 from xpresso._utils.routing import visit_routes
-from xpresso.dependencies.models import Depends, Scopes
+from xpresso.dependencies import Depends, Scopes
 from xpresso.exception_handlers import (
     ExcHandler,
     http_exception_handler,
@@ -356,12 +356,16 @@ def _build_middleware_stack(
 def _wrap_lifespan_as_async_generator(
     lifespan: typing.Callable[..., typing.AsyncContextManager[None]]
 ) -> typing.Callable[..., typing.AsyncIterator[None]]:
+    # wrap true context managers in an async generator
+    # so that the dependency injection system recognizes it
     async def gen(
         *args: typing.Any, **kwargs: typing.Any
     ) -> typing.AsyncIterator[None]:
         async with lifespan(*args, **kwargs):
             yield
 
+    # this is so that the dependency injection system
+    # still picks up parameters from the function signature
     sig = inspect.signature(gen)
     sig = sig.replace(parameters=list(inspect.signature(lifespan).parameters.values()))
     setattr(gen, "__signature__", sig)
